package net.ecoop.android.viewlifecycle;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

@SuppressLint("ShowToast")
public class CustomView extends View {
	private RectF rect;
	private Paint paint;

	public CustomView(Context context) {
		super(context);
		Logger.log(getContext(), "View(Context)");
		init();
	}

	public CustomView(Context context, AttributeSet attrs) {
		super(context, attrs);
		Logger.log(getContext(), "View(Context,AttributeSet)");
		init();
	}

	public CustomView(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		Logger.log(getContext(), "View(Context,AttributeSet,int)");
		init();
	}

	private void init() {
		rect = new RectF(0, 0, 50, 50);
		paint = new Paint();
		paint.setColor(Color.BLACK);
	}

	@Override
	protected void onAttachedToWindow() {
		super.onAttachedToWindow();
		Logger.log(getContext(), "onAttachedToWindow()");
	}

	@Override
	protected void onDetachedFromWindow() {
		super.onDetachedFromWindow();
		Logger.log(getContext(), "onDetachedToWindow()");
	}

	@Override
	protected void onDraw(Canvas canvas) {
		super.onDraw(canvas);
		Logger.log(getContext(), "onDraw()");
		canvas.drawRect(rect, paint);
	}

	@Override
	protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
		super.onMeasure(widthMeasureSpec, heightMeasureSpec);
		Logger.log(getContext(), "onMeasure()");
	}

	@Override
	protected void onLayout(boolean changed, int left, int top, int right,
			int bottom) {
		super.onLayout(changed, left, top, right, bottom);
		Logger.log(getContext(), "onLayout(" + (changed ? "true" : "false") + ", ...)");
	}
	@Override
	protected void onFinishInflate() {
		super.onFinishInflate();
		Logger.log(getContext(), "onFinishInflate())");
	}
}
